@@ -26,6 +26,19 @@
 
 #include <epoxy/gl.h>
 
+// qopengl.h declares GLdouble as a typedef of float when Qt is built
+// with GLES support.  This conflicts with the epoxy/gl_generated.h
+// declaration, so we have to prevent the Qt header from being #included.
+#define QOPENGL_H
+
+#ifndef QOPENGLF_APIENTRY
+#define QOPENGLF_APIENTRY GLAPIENTRY
+#endif
+
+#ifndef QOPENGLF_APIENTRYP
+#define QOPENGLF_APIENTRYP GLAPIENTRYP
+#endif
+
 #include <QSGTexture>
 #include <QSGSimpleTextureNode>
 #include <QQuickItem>
@@ -34,6 +47,8 @@
 #include <QQuickWindow>
 #include <QMutex>
 
+class ManagedTextureNode;
+
 /**
  * a Plotter can draw a graph of values arriving from an arbitrary number of data sources
  * to show their evoluton in time.
@@ -227,7 +242,7 @@ private:
     QList<PlotData *> m_plotData;
 
     GLuint m_fbo = 0;
-    QSGSimpleTextureNode *m_node = nullptr;
+    ManagedTextureNode *m_node = nullptr;
     qreal m_min;
     qreal m_max;
     qreal m_rangeMax;
